@@ -2,11 +2,12 @@
 # google_translator.py <Peter.Bienstman@UGent.be>
 #
 
-from googletrans import Translator as gTranslator
-
 from mnemosyne.libmnemosyne.gui_translator import _
 from mnemosyne.libmnemosyne.translator import Translator
 
+#from google_trans_new import google_translator
+from googletrans import Translator as google_translator
+translator = None
 
 class GoogleTranslator(Translator):
 
@@ -25,8 +26,24 @@ class GoogleTranslator(Translator):
 
     popup_menu_text = "Insert Google translation..."
 
-    def translate(self, card_type, foreign_text, target_language_id):
+    def translate(self, card_type, foreign_text, target_language_id,
+                  retries=0):
+        global translator
+        if not translator:
+            translator = google_translator()
         source_language_id = self.config().card_type_property(\
             "language_id", card_type)
-        return gTranslator().translate(foreign_text, target_language_id,
-                source_language_id).text
+        try:
+            #result = translator.translate(foreign_text,
+            #    lang_tgt=target_language_id, lang_src=source_language_id).strip()
+            result = translator.translate(foreign_text,
+                dest=target_language_id, src=source_language_id).text.strip()
+        except:
+            if retries < 5:
+                import time; time.sleep(2)
+                translator = google_translator()
+                return self.translate(card_type, foreign_text,
+                    target_language_id, retries=retries+1)
+            else:
+                return None
+        return result
