@@ -449,6 +449,9 @@ class BrowseCardsDlg(QtWidgets.QDialog, BrowseCardsDialog,
         delete_action.setShortcut(QtGui.QKeySequence.Delete)
         delete_action.triggered.connect(self.menu_delete)
         menu.addAction(delete_action)
+        reset_action = QtWidgets.QAction(_("Reset"), menu)
+        reset_action.triggered.connect(self.menu_reset)
+        menu.addAction(reset_action)
         menu.addSeparator()
         change_card_type_action = QtWidgets.QAction(_("Change card &type"), menu)
         change_card_type_action.triggered.connect(self.menu_change_card_type)
@@ -711,6 +714,29 @@ class BrowseCardsDlg(QtWidgets.QDialog, BrowseCardsDialog,
         self.load_qt_database()
         self.display_card_table()
 
+    def menu_reset(self):
+        answer = self.main_widget().show_question\
+            (_("Reset history of selected cards? Sister cards will be reset as well."),
+            _("&OK"), _("&Cancel"), "")
+        if answer == 1: # Cancel.
+            return
+        _fact_ids = set()
+        for index in self.table.selectionModel().selectedRows():
+            _fact_id_index = index.model().index(\
+                index.row(), _FACT_ID, index.parent())
+            _fact_id = index.model().data(_fact_id_index)
+            _fact_ids.add(_fact_id)
+        facts = []
+        for _fact_id in _fact_ids:
+            facts.append(self.database().fact(_fact_id, is_id_internal=True))
+        self.unload_qt_database()
+        self.selected_rows = []
+        self.controller().reset_facts_and_their_cards(facts)
+        self.card_type_tree_wdgt.rebuild()
+        self.tag_tree_wdgt.rebuild()
+        self.load_qt_database()
+        self.display_card_table()
+
     def load_qt_database(self):        
         self.database().release_connection()
         qt_db = QtSql.QSqlDatabase.addDatabase("QSQLITE")
@@ -754,8 +780,6 @@ class BrowseCardsDlg(QtWidgets.QDialog, BrowseCardsDialog,
         # Slow, and doesn't work very well.
         #self.table.verticalHeader().setSectionResizeMode(\
         #    QtWidgets.QHeaderView.ResizeToContents)
-        self.table.horizontalHeader().sectionClicked.connect(\
-            self.horizontal_header_section_clicked)
         table_settings = self.config()["browse_cards_dlg_table_settings"]
         if table_settings:
             self.table.horizontalHeader().restoreState(table_settings)
@@ -802,12 +826,6 @@ class BrowseCardsDlg(QtWidgets.QDialog, BrowseCardsDialog,
         self.load_qt_database()
         self.display_card_table()
 
-    def horizontal_header_section_clicked(self, index):
-        if not self.config()["browse_cards_dlg_sorting_warning_shown"]:
-            self.main_widget().show_information(\
-_("You chose to sort this table. Operations in the card browser could now be slower. Next time you start the card browser, the table will be unsorted again."))
-            self.config()["browse_cards_dlg_sorting_warning_shown"] = True
-
     def activate(self):
         BrowseCardsDialog.activate(self)
         self.exec_()
