@@ -109,8 +109,8 @@ class QTextEdit2(QtWidgets.QTextEdit):
             QtWidgets.QTextEdit.keyPressEvent(self, event)
 
     def insert_img(self):
-        filter = "(*.png *.gif *.jpg *.bmp *.jpeg *.svg *.tiff" + \
-                 " *.PNG *.GIF *.jpg *.BMP *.JPEG *.SVG *.TIFF)"
+        filter = "(*.png *.gif *.jpg *.bmp *.jpeg *.svg *.tiff *.webp" + \
+                 " *.PNG *.GIF *.JPG *.BMP *.JPEG *.SVG *.TIFF *.WEBP)"
         filename = self.parent().controller().show_insert_img_dialog(filter)
         if filename:
             self.insertPlainText("<img src=\"" + filename + "\">")
